@@ -1,7 +1,7 @@
+from vatis.asr_commons.domain.word import Word
 from vatis.asr_commons.domain.transcriber import DataPacket
 from vatis.asr_commons.domain.transcriber import ByteDataPacket
 from vatis.asr_commons.domain.transcriber import TranscriptionPacket
-from vatis.asr_commons.domain.transcriber import Word
 from vatis.asr_commons.domain.transcriber import TimestampedTranscriptionPacket
 from vatis.asr_commons.domain.transcriber import NdArrayDataPacket
 from vatis.asr_commons.domain.transcriber import LogitsDataPacket
